@@ -1,7 +1,7 @@
 package App::BashHistoryUtils;
 
-our $DATE = '2015-11-07'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-11-09'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -60,7 +60,6 @@ sub _do {
     require Bash::History::Read;
     require Capture::Tiny;
     require Cwd;
-    #require File::Temp;
 
     my $which = shift;
     my %args = @_;
@@ -125,10 +124,11 @@ sub _do {
 
     if ($which eq 'grep' ||
             $which eq 'each' ||
-            $which eq 'delete' && $args{-dry_run}) {
+            $which eq 'delete' && ($args{-dry_run} || !$args{inplace})) {
         return [200,"OK", $stdout, {'cmdline.skip_format'=>1}];
     } elsif ($which eq 'delete') {
-        my $tempfile = "$realhistfile.tmp.$$";
+        require File::Temp;
+        my ($tempfh, $tempfile) = File::Temp::tempfile(template => "${realhistfile}XXXXXX");
         open my($fh), ">", $tempfile
             or return [500, "Can't open temporary file '$tempfile': $!"];
 
@@ -138,6 +138,8 @@ sub _do {
         close $fh
             or return [500, "Can't write (2) to temporary file '$tempfile': $!"];
 
+        rename $realhistfile, "$realhistfile~"
+            or warn "Can't move '$realhistfile' to '$realhistfile~': $!";
         rename $tempfile, $realhistfile
             or return [500, "Can't replace temporary file '$tempfile' to '$realhistfile': $!"];
     }
@@ -165,6 +167,10 @@ $SPEC{delete_bash_history_entries} = {
         %arg_histfile,
         %args_filtering,
         %args_formatting,
+        inplace => {
+            summary => 'Replace original bash history file',
+            schema => ['bool', is=>1],
+        },
     },
     features => {
         dry_run => 1,
@@ -218,7 +224,7 @@ App::BashHistoryUtils - CLI utilities related to bash history file
 
 =head1 VERSION
 
-This document describes version 0.03 of App::BashHistoryUtils (from Perl distribution App-BashHistoryUtils), released on 2015-11-07.
+This document describes version 0.04 of App::BashHistoryUtils (from Perl distribution App-BashHistoryUtils), released on 2015-11-09.
 
 =head1 DESCRIPTION
 
@@ -254,6 +260,10 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ignore_case> => I<bool>
 
+=item * B<inplace> => I<bool>
+
+Replace original bash history file.
+
 =item * B<invert_match> => I<bool>
 
 =item * B<max_age> => I<duration>
